!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!                                          numgeo
!                Copyright (C) 2018-2023 Jan Machacek, Patrick Staubach
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!
! SUBROUTINE: user_initial_stress
!
!> author: Jan Machacek, jan-machacek@outlook.com
!> date: 27.03.2019
!
!> Interface to user subroutine to define the initial (effective) stress `stress`
!
!>### History
!> 27.03.2019, J. Machacek - Initial version
!> 26.05.2023, J. Machacek - Bugfix of string passing through user-interface
!> 05.07.2023, P. Staubach - Windows version
!
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
subroutine user_initial_stress(ie,igp,ndim,ntens,nchar,material,coords,stress) 
  implicit none
  !DEC$ ATTRIBUTES DLLEXPORT, STDCALL, REFERENCE :: user_initial_stress
  integer                  , intent(in)    :: ie           !! element label
  integer                  , intent(in)    :: igp          !! integration point label
  integer                  , intent(in)    :: ndim         !! number of active dimensions
  integer                  , intent(in)    :: ntens        !! number of stress components
  integer                  , intent(in)    :: nchar        !! length of the material name
  character                , intent(in)    :: material(*)  !! material name
  real(8), dimension(3)    , intent(in)    :: coords       !! coordinates of the integration point
  real(8), dimension(ntens), intent(inout) :: stress       !! initial stress

  character(len=nchar) :: material_str
  
   real(8) :: htop,KO,pO,gammaW,gammaS,n,evoid_ini,gamma,gamma_eff

   KO=0.4d0
   pO =0.0d0
   gammaW = 1.0d0 * 10.d0
   gammaS = 2.65d0 * 10.d0

	
	! corresponds to the "real" density
   evoid_ini = 0.8655
   
   ! porosity
   n = evoid_ini/(1.+evoid_ini)
   
   gamma = (1. - n) * gammaS + n * gammaW
   gamma_eff = (1.-n)*gammaS + n*gammaW - gammaW
   
   stress = 0.0d0
   stress(3) = -coords(3) * gamma_eff
   stress(2) = (stress(3) ) * KO
   stress(1) = stress(2)

end subroutine user_initial_stress
